@@ -1,21 +1,15 @@
 import { Op } from 'sequelize';
-import config from 'config';
 import { chunk, omit, omitBy } from 'lodash';
 import { VISIBILITY_STATUSES } from '@tamanu/constants';
 import { NOTE_RECORD_TYPES } from '@tamanu/constants/notes';
 import { InvalidParameterError } from '@tamanu/shared/errors';
 import { log } from '@tamanu/shared/services/logging';
-import { refreshChildRecordsForSync } from '@tamanu/shared/utils/refreshChildRecordsForSync';
 
 const BULK_CREATE_BATCH_SIZE = 100;
 
 // These ones just need a patientId switched over.
 // Models included here will just have their patientId field
 // redirected to the new patient and that's all.
-
-// IMPORTANT: Any models here that have child records, please add the logic to handle them
-// in:
-// - updateDependentRecordsForResync function in this file
 export const simpleUpdateModels = [
   'Encounter',
   'PatientAllergy',
@@ -39,10 +33,6 @@ export const simpleUpdateModels = [
 // These ones need a little more attention.
 // Models in this array will be ignored by the automatic pass
 // so that they can be handled elsewhere.
-
-// IMPORTANT: Any models here that have child records, please add the logic to handle them
-// in:
-// - updateDependentRecordsForResync function in this file
 export const specificUpdateModels = [
   'Patient',
   'PatientAdditionalData',
@@ -77,6 +67,10 @@ const omittedColumns = [
   'updatedAtByField',
 ];
 
+// This is for cases where we never want to update the patient_id
+// even after merge
+const omittedModels = ['AccessLog'];
+
 function isNullOrEmptyString(value) {
   return value === null || value === '';
 }
@@ -99,7 +93,7 @@ const modelReferencesPatient = ([, model]) =>
 export async function getTablesWithNoMergeCoverage(models) {
   const modelsToUpdate = Object.entries(models).filter(modelReferencesPatient);
 
-  const coveredModels = [...simpleUpdateModels, ...specificUpdateModels];
+  const coveredModels = [...simpleUpdateModels, ...specificUpdateModels, ...omittedModels];
   const missingModels = modelsToUpdate.filter(([name]) => !coveredModels.includes(name));
 
   return missingModels;
@@ -355,49 +349,7 @@ export async function reconcilePatientFacilities(models, keepPatientId, unwanted
   return newPatientFacilities;
 }
 
-export async function refreshMultiChildRecordsForSync(model, records) {
-  for (const record of records) {
-    await refreshChildRecordsForSync(model, record.id);
-  }
-}
-
-/**
- * Due to the generic cascade deletion hook, when the unwanted patient deletion is synced down to facility,
- * all dependent records that are not updated as part of this transaction will also be soft deleted in facility.
- * Hence, we need to update the dependent records of unwanted patient in this transaction, so that they are not soft deleted.
- * @param {*} models
- * @param {*} unwantedPatientId
- */
-async function updateDependentRecordsForResync(models, unwantedPatientId) {
-  // Encounters
-  const encounters = await models.Encounter.findAll({
-    where: { patientId: unwantedPatientId },
-    attributes: ['id'],
-  });
-  await refreshMultiChildRecordsForSync(models.Encounter, encounters);
-
-  // Patient Care Plans
-  const patientCarePlans = await models.PatientCarePlan.findAll({
-    where: { patientId: unwantedPatientId },
-    attributes: ['id'],
-  });
-  await refreshMultiChildRecordsForSync(models.PatientCarePlan, patientCarePlans);
-
-  // Patient Death Data
-  const patientDeathDataRecords = await models.PatientDeathData.findAll({
-    where: { patientId: unwantedPatientId },
-    attributes: ['id'],
-  });
-  await refreshMultiChildRecordsForSync(models.PatientDeathData, patientDeathDataRecords);
-}
-
-export async function mergePatient(
-  models,
-  keepPatientId,
-  unwantedPatientId,
-  updateDependentRecordsForResyncEnabled = config.patientMerge
-    .updateDependentRecordsForResyncEnabled,
-) {
+export async function mergePatient(models, keepPatientId, unwantedPatientId) {
   const { sequelize } = models.Patient;
 
   if (keepPatientId === unwantedPatientId) {
@@ -433,11 +385,6 @@ export async function mergePatient(
       visibilityStatus: VISIBILITY_STATUSES.MERGED,
     });
 
-    // See the function's documentation for more details on why this is needed
-    if (updateDependentRecordsForResyncEnabled) {
-      await updateDependentRecordsForResync(models, unwantedPatientId);
-    }
-
     updates.Patient = 2;
 
     // update associated records
