@@ -2,7 +2,7 @@ import { trace } from '@opentelemetry/api';
 import { Op, QueryTypes } from 'sequelize';
 import _config from 'config';
 
-import { DEBUG_LOG_TYPES, SETTINGS_SCOPES } from '@tamanu/constants';
+import { DEBUG_LOG_TYPES, SETTINGS_SCOPES, AUDIT_PAUSE_KEY } from '@tamanu/constants';
 import { FACT_CURRENT_SYNC_TICK, FACT_LOOKUP_UP_TO_TICK } from '@tamanu/constants/facts';
 import { log } from '@tamanu/shared/services/logging';
 import {
@@ -582,6 +582,11 @@ export class CentralSyncManager {
     try {
       // commit the changes to the db
       const persistedAtSyncTick = await sequelize.transaction(async () => {
+        // Don't produce audit logs for changes made through sync
+        // Audit changelogs are generated on facility servers and will sync in to central
+        // Mobile changelogs are currently not implemented
+        await sequelize.setTransactionVar(AUDIT_PAUSE_KEY, true);
+
         // we tick-tock the global clock to make sure there is a unique tick for these changes
         // n.b. this used to also be used for concurrency control, but that is now handled by
         // shared advisory locks taken using the current sync tick as the id, which are waited on
@@ -603,11 +608,6 @@ export class CentralSyncManager {
           { direction: SYNC_SESSION_DIRECTION.INCOMING },
         );
 
-        // Tick tock once more to ensure that no records that are subsequently modified will share the same sync tick as the incoming changes
-        // notably so that if records are modified by adjustDataPostSyncPush(), they will be picked up for pulling in the same session
-        // (specifically won't be removed by removeEchoedChanges())
-        await this.tickTockGlobalClock();
-
         return tock;
       });
 
@@ -615,6 +615,9 @@ export class CentralSyncManager {
         deviceId,
         persistedAtSyncTick,
       });
+      // tick tock global clock so that if records are modified by adjustDataPostSyncPush(),
+      // they will be picked up for pulling in the same session (specifically won't be removed by removeEchoedChanges())
+      await this.tickTockGlobalClock();
       await adjustDataPostSyncPush(sequelize, modelsToInclude, sessionId);
 
       // mark for repull any records that were modified by an incoming sync hook
